﻿
#include "StdAfx.h"
#include "SettingMessage.h"
#include "CommonFunction.h"
#include "UIMenu.h"
#include "main_frame.hpp"
#include "NeMessengerDlg.h"



const TCHAR* const kSettingNotifyOnNewsCheck = _T("notifyOnNews_check");
const TCHAR* const kSettingNoNotifyMobileCheck = _T("donotNotifyMobile_check");
const TCHAR* const kSettingNotifyWayCheck = _T("NotifyWay_check");
const TCHAR* const kSettingNotifyMsnCheck = _T("NotifyMsn_check");

const TCHAR* const kSettingSoundCheck = _T("Sound_check");
const TCHAR* const kSettingOffChatSoundCheck = _T("OffChatSound_check");
const TCHAR* const kSettingOffMsgSoundCheck = _T("OffMsg_check");
const TCHAR* const kSettingOfflineCheck = _T("OffWhenOffline_check");

CSettingMessage::CSettingMessage(CPaintManagerUI& m_pManager):b_notifyOnNews(1)
,b_shieldMobile(1)
,b_TrayOnLogin(1)
,b_NotifyOnMailOrSMS(1)
,b_SoundOn(1)
,b_OffChatSound(0)
,b_OffMsgSound(0)
,b_OffSoundNotOnline(0)
,minute(10)
,paint_manager_(m_pManager)
{
    
	CreateControl();
}

CSettingMessage::~CSettingMessage()
{

}

bool CSettingMessage::DoApply(){
	
	GET_CONFIG()->SetAllSound( (b_SoundOn == 1) ? 1:0 );
	GET_CONFIG()->SetNoteSound((b_OffMsgSound == 0) ? 1:0); 
	GET_CONFIG()->SetChatSound((b_OffChatSound == 0) ? 1:0);
	GET_CONFIG()->SetSoundNotOnline( (b_OffSoundNotOnline == 0) ? 1:0 );

	GET_CONFIG()->SetNotifyOnNews((b_notifyOnNews == 1) ? 1:0); 
	GET_CONFIG()->SetNotifyOnMailOrSMS((b_NotifyOnMailOrSMS == 1) ? 1:0);
	GET_CONFIG()->SetShieldMobile( (b_shieldMobile == 1) ? 1:0 );
	GET_CONFIG()->SetFavoriteTray((b_TrayOnLogin == 1) ? 1:0); 	
	return true;

}

void CSettingMessage::InitData(){	
	
	b_SoundOn = (GET_CONFIG()->GetAllSound() == 1) ? 1:0;
	b_OffMsgSound = (GET_CONFIG()->GetNoteSound() == 1) ? 0:1;
	b_OffChatSound = (GET_CONFIG()->GetChatSound() == 1) ? 0:1;
	b_OffSoundNotOnline = (GET_CONFIG()->GetSoundNotOnline() == 1) ? 0:1;

	b_notifyOnNews = (GET_CONFIG()->GetNotifyOnNews() == 1) ? 1:0;
	b_NotifyOnMailOrSMS = (GET_CONFIG()->GetNotifyOnMailOrSMS() == 1) ? 1:0;
	b_shieldMobile = (GET_CONFIG()->GetShieldMobile() == 1) ? 1:0;
	b_TrayOnLogin = (GET_CONFIG()->GetFavoriteTray() == 1) ? 1:0; 

}

void CSettingMessage::CreateControl()
{
	CDialogBuilder builder;
	CContainerUI* pContainerUI = static_cast<CContainerUI*>(builder.Create(_T("setting_message.xml"), (UINT)0, (UINT)0, 
		&paint_manager_));
	if( pContainerUI != NULL ) 
	{
		this->Add(pContainerUI);
	}
	else 
	{
		this->RemoveAll();
		return;
	}
}

void CSettingMessage::SetCheckBtnCheck(CControlUI *pBtnContrl, int checked){
	CButtonUI* pCheckBox = (CButtonUI*)pBtnContrl;
   if (pBtnContrl)
   {
       if (1 == checked)
       {
		   pCheckBox->SetNormalImage(_T("btn_chat_talk_checkboc_on.png"));

       } 
       else
       {
		   pCheckBox->SetNormalImage(_T("btn_chat_talk_checkboc_off.png"));

       }

   }
   pCheckBox->NeedUpdate();
}

void CSettingMessage::NotifyCtrlClick(TNotifyUI& msg)
{
	if (_tcsicmp(msg.pSender->GetName(), kSettingNotifyOnNewsCheck) == 0)
	{
	     b_notifyOnNews = ( b_notifyOnNews== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_notifyOnNews);
	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingNoNotifyMobileCheck) == 0)
	{
		b_shieldMobile = ( b_shieldMobile== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_shieldMobile);

	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingNotifyWayCheck) == 0)
	{
		b_TrayOnLogin = ( b_TrayOnLogin== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_TrayOnLogin);
	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingNotifyMsnCheck) == 0)
	{
		b_NotifyOnMailOrSMS = ( b_NotifyOnMailOrSMS== 1)? 0:1;
	    SetCheckBtnCheck(msg.pSender,b_NotifyOnMailOrSMS);
	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingSoundCheck) == 0)
	{
		
		b_SoundOn = ( b_SoundOn== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_SoundOn);
		if (b_SoundOn)
		{
			b_OffChatSound = 0;
			b_OffMsgSound = 0;
			b_OffSoundNotOnline = 0;
			CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffChatSoundCheck));
			SetCheckBtnCheck(pCtrl,b_OffChatSound);
			pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffMsgSoundCheck));//rule board1
			SetCheckBtnCheck(pCtrl,b_OffMsgSound);
			pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));//rule board1
			SetCheckBtnCheck(pCtrl,b_OffSoundNotOnline);
		}
		else{
          b_OffChatSound = 1;
		  b_OffMsgSound = 1;
		  b_OffSoundNotOnline = 1;
		  CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffChatSoundCheck));
          SetCheckBtnCheck(pCtrl,b_OffChatSound);
		  pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffMsgSoundCheck));//rule board1
		  SetCheckBtnCheck(pCtrl,b_OffMsgSound);
		  pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));//rule board1
		  SetCheckBtnCheck(pCtrl,b_OffSoundNotOnline);
		}
	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingOffChatSoundCheck) == 0)
	{
		b_OffChatSound = ( b_OffChatSound== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_OffChatSound);
        
		if (b_OffChatSound== 1 && b_OffMsgSound == 1 )
		{
			b_SoundOn = 0;
			b_OffSoundNotOnline = 1;
			CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pCtrl,b_SoundOn);
			pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));
			SetCheckBtnCheck(pCtrl,b_OffSoundNotOnline);
		}
		else{
           b_SoundOn = 1;
		   CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
		   SetCheckBtnCheck(pCtrl,b_SoundOn);

		}
	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingOffMsgSoundCheck) == 0)
	{
		b_OffMsgSound = ( b_OffMsgSound== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_OffMsgSound);
		if (b_OffChatSound== 1 && b_OffMsgSound == 1 )
		{
			b_SoundOn = 0;
			b_OffSoundNotOnline = 1;
			CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pCtrl,b_SoundOn);
			pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));
			SetCheckBtnCheck(pCtrl,b_OffSoundNotOnline);
		}
		else{
			b_SoundOn = 1;
			CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pCtrl,b_SoundOn);

		}
	}
	else if (_tcsicmp(msg.pSender->GetName(), kSettingOfflineCheck) == 0)
	{
		b_OffSoundNotOnline = ( b_OffSoundNotOnline== 1)? 0:1;
		SetCheckBtnCheck(msg.pSender,b_OffSoundNotOnline);
		if (b_OffChatSound== 1 && b_OffMsgSound == 1 )
		{
			b_SoundOn = 0;
			b_OffSoundNotOnline = 1;
			CControlUI* pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pCtrl,b_SoundOn);
			pCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));
			SetCheckBtnCheck(pCtrl,b_OffSoundNotOnline);
		}
	}
}


void CSettingMessage::ProcLabelEvent(CControlUI* pCtrl){

	if( pCtrl != NULL ) 
	{
	if (!_tcsicmp(pCtrl->GetName(),_T("notifyOnNews_label")))
	{
		b_notifyOnNews = ( b_notifyOnNews== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(_T("notifyOnNews_check")));
		SetCheckBtnCheck(pCheckBtn,b_notifyOnNews);
	} 
	else if (!_tcsicmp(pCtrl->GetName(),_T("donotNotifyMobile_label")))
	{
		b_shieldMobile = ( b_shieldMobile== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(_T("donotNotifyMobile_check")));
		SetCheckBtnCheck(pCheckBtn,b_shieldMobile);
	}

	else if (!_tcsicmp(pCtrl->GetName(),_T("NotifyWay_label")))
	{
		b_TrayOnLogin = ( b_TrayOnLogin== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(_T("NotifyWay_check")));
		SetCheckBtnCheck(pCheckBtn,b_TrayOnLogin);

	}
	else if (!_tcsicmp(pCtrl->GetName(),_T("NotifyMsg_label")))
	{
		b_NotifyOnMailOrSMS = ( b_NotifyOnMailOrSMS== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(_T("NotifyMsn_check")));
		SetCheckBtnCheck(pCheckBtn,b_NotifyOnMailOrSMS);

	}
	else if (!_tcsicmp(pCtrl->GetName(),_T("Sound_label")))
	{
		b_SoundOn = ( b_SoundOn== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
		SetCheckBtnCheck(pCheckBtn,b_SoundOn);
		if (b_SoundOn)
		{
			b_OffChatSound = 0;
			b_OffMsgSound = 0;
			b_OffSoundNotOnline = 0;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffChatSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_OffChatSound);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffMsgSoundCheck));//rule board1
			SetCheckBtnCheck(pInnerCtrl,b_OffMsgSound);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));//rule board1
			SetCheckBtnCheck(pInnerCtrl,b_OffSoundNotOnline);
		}
		else{
			b_OffChatSound = 1;
			b_OffMsgSound = 1;
			b_OffSoundNotOnline = 1;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffChatSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_OffChatSound);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffMsgSoundCheck));//rule board1
			SetCheckBtnCheck(pInnerCtrl,b_OffMsgSound);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));//rule board1
			SetCheckBtnCheck(pInnerCtrl,b_OffSoundNotOnline);
		}

	}
	else if(0 ==_tcsicmp(pCtrl->GetName(),_T("OffChatSound_label")))
	{
		b_OffChatSound = ( b_OffChatSound== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffChatSoundCheck));
		SetCheckBtnCheck(pCheckBtn,b_OffChatSound);

		if (b_OffChatSound== 1 && b_OffMsgSound == 1 )
		{
			b_SoundOn = 0;
			b_OffSoundNotOnline = 1;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_SoundOn);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));
			SetCheckBtnCheck(pInnerCtrl,b_OffSoundNotOnline);
		}
		else{
			b_SoundOn = 1;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_SoundOn);

		}
	}
	else if (!_tcsicmp(pCtrl->GetName(),_T("OffMsg_label")))
	{
		b_OffMsgSound = ( b_OffMsgSound== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOffMsgSoundCheck));

		SetCheckBtnCheck(pCheckBtn,b_OffMsgSound);
		if (b_OffChatSound== 1 && b_OffMsgSound == 1 )
		{
			b_SoundOn = 0;
			b_OffSoundNotOnline = 1;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_SoundOn);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));
			SetCheckBtnCheck(pInnerCtrl,b_OffSoundNotOnline);
		}
		else{
			b_SoundOn = 1;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_SoundOn);

		}
	}
	else if (!_tcsicmp(pCtrl->GetName(),_T("OffWhenOffline_label")))
	{
		b_OffSoundNotOnline = ( b_OffSoundNotOnline== 1)? 0:1;
		CControlUI* pCheckBtn =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));

		SetCheckBtnCheck(pCheckBtn,b_OffSoundNotOnline);
		if (b_OffChatSound== 1 && b_OffMsgSound == 1 )
		{
			b_SoundOn = 0;
			b_OffSoundNotOnline = 1;
			CControlUI* pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingSoundCheck));
			SetCheckBtnCheck(pInnerCtrl,b_SoundOn);
			pInnerCtrl =static_cast<CControlUI*>(m_pManager->FindControl(kSettingOfflineCheck));
			SetCheckBtnCheck(pInnerCtrl,b_OffSoundNotOnline);
		}
	}
}




}

static bool OnTextEvent(void* event) {
	TEventUI *pEvent = (TEventUI*)event;
	static CString strOldImage = _T("");
	if( ((TEventUI*)event)->Type == UIEVENT_BUTTONDOWN ) {
		CControlUI* pCtrl= ((TEventUI*)event)->pSender;
		CSettingMessage *pthis = (CSettingMessage *)pCtrl->GetTag();
        pthis->ProcLabelEvent(pCtrl);
		
	}
	else if( ((TEventUI*)event)->Type == UIEVENT_MOUSEENTER){
		SetCursor(AfxGetApp()->LoadStandardCursor(IDC_HAND));
	}
	else if( ((TEventUI*)event)->Type == UIEVENT_MOUSELEAVE){
		SetCursor(AfxGetApp()->LoadStandardCursor(IDC_ARROW));
	}
	else if( ((TEventUI*)event)->Type == UIEVENT_MOUSEHOVER){
		SetCursor(AfxGetApp()->LoadStandardCursor(IDC_HAND));
	}
	else if( ((TEventUI*)event)->Type == UIEVENT_MOUSEMOVE){
		SetCursor(AfxGetApp()->LoadStandardCursor(IDC_HAND));
	}
	return true;
}
static int minute_offline[] = {3,5,10,15,20,30}; 

void CSettingMessage::InitControl()
{
	CSize szAvail(285,20);
	CLabelUI* pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("rules"))); // rules
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGRULES));
	}
	CTextUI *pText = static_cast<CTextUI*>(m_pManager->FindControl(_T("notifyOnNews_label")));//rule board1
	if (pText != NULL)
	{
		pText->OnEvent += MakeDelegate(OnTextEvent);
		pText->SetTag(UINT_PTR(this));
		pText->SetText(LoadStringFromResource(IDS_STRINGNOTIFYNEWS));
		
	}
	pText = static_cast<CTextUI*>(m_pManager->FindControl(_T("donotNotifyMobile_label"))); //rule board2
	if (pText != NULL)
	{
		pText->OnEvent += MakeDelegate(OnTextEvent);
		pText->SetTag(UINT_PTR(this));

		pText->SetText(LoadStringFromResource(IDS_STRINGSHIELDMOBILE));	
		CHorizontalLayoutUI* pHorizon = static_cast<CHorizontalLayoutUI*>(m_pManager->FindControl(_T("rulesBoard2"))); 
		CSize sz = pText->EstimateSize(szAvail);
		if (sz.cy > szAvail.cy) 
		{
			pText->SetAttribute(_T("align"), _T("leftVcenter"));
			pHorizon->SetFixedHeight(sz.cy);
		}
		else{
           pText->SetAttribute(_T("align"), _T("left"));
		   pHorizon->SetFixedHeight(sz.cy);
		}
		pHorizon->NeedUpdate();
		pText->NeedUpdate();
	}
	 pText = static_cast<CTextUI*>(m_pManager->FindControl(_T("offlineLabel"))); //rule board3: combo and text
	if (pText != NULL)
	{
	    CString str = LoadStringFromResource(IDS_STRINGMINUTE);
		str += _T("  ");
		str += LoadStringFromResource(IDS_STRINGMOBILERECEIVED);
		pText->SetText(str);
		CHorizontalLayoutUI* pHorizon = static_cast<CHorizontalLayoutUI*>(m_pManager->FindControl(_T("rulesBoard3"))); 
		CSize szLimit(219,0);
		CSize sz = pText->EstimateSize(szLimit);
		if (sz.cy > 26) // 26 is height of combobox;
		{
			pText->SetAttribute(_T("align"), _T("leftVcenter"));
			pHorizon->SetFixedHeight(sz.cy);
		}
		else{
			pText->SetAttribute(_T("align"), _T("left"));
			pHorizon->SetFixedHeight(26);
		}
		pHorizon->NeedUpdate();
		pText->NeedUpdate();
	}
    CComboExUI* combo_time = static_cast<CComboExUI*>(m_pManager->FindControl(_T("message_time_combo")));
	if (combo_time != NULL)
	{
		combo_time->RemoveAll();

		CListLabelElementUI* item = NULL;
		CString str;

		for(int i = 0; i < sizeof(minute_offline)/sizeof(int); i++)
		{
			str.Format(_T("%d"),minute_offline[i]);

			item = new CListLabelElementUI();
			item->SetText(str);
			combo_time->Add(item);
		}

		combo_time->SetInternVisible();
		combo_time->SelectItem(1);
	}
	


	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("notifyWay_Text"))); //method label;
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGNOTIMETHOD));
	}

	pText = static_cast<CTextUI*>(m_pManager->FindControl(_T("NotifyWay_label"))); //login tip method
	if (pText != NULL)
	{
		pText->OnEvent += MakeDelegate(OnTextEvent);
		pText->SetTag(UINT_PTR(this));

		pText->SetText(LoadStringFromResource(IDS_STRINGNOTIFYLOGIN));
		CHorizontalLayoutUI* pHorizon = static_cast<CHorizontalLayoutUI*>(m_pManager->FindControl(_T("notifyWayBoard"))); 
		CSize sz = pText->EstimateSize(szAvail);
		if (sz.cy > szAvail.cy) // 26 is height of combobox;
		{
			pText->SetAttribute(_T("align"), _T("leftVcenter"));
			pText->SetLineInterval(7);
			pHorizon->SetFixedHeight(sz.cy + 7);
		}
		else{
			pText->SetAttribute(_T("align"), _T("left"));
			pHorizon->SetFixedHeight(szAvail.cy);
		}
		pHorizon->NeedUpdate();
		pText->NeedUpdate();
	}

	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("notifyMsg_text")));// mail/note tip
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGNOTIFYMAIL));
	}

	pText = static_cast<CTextUI*>(m_pManager->FindControl(_T("NotifyMsg_label"))); 
	if (pText != NULL)
	{
		pText->SetText(LoadStringFromResource(IDS_STRINGNOTIFYMAISNS));
		pText->OnEvent += MakeDelegate(OnTextEvent);
		pText->SetTag(UINT_PTR(this));

	}

	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("Sound_text")));  //sound
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGSOUND));

	}

	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("Sound_label")));
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGSOUNDON));
		pLabel->OnEvent += MakeDelegate(OnTextEvent);
		pLabel->SetTag(UINT_PTR(this));

	}
	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("OffChatSound_label")));
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGSOUNDOFFCHAT));
		pLabel->OnEvent += MakeDelegate(OnTextEvent);
		pLabel->SetTag(UINT_PTR(this));

	}
	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("OffMsg_label")));
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGSOUNDOFFNOTI));
		pLabel->OnEvent += MakeDelegate(OnTextEvent);
		pLabel->SetTag(UINT_PTR(this));

	}
	pLabel = static_cast<CLabelUI*>(m_pManager->FindControl(_T("OffWhenOffline_label")));
	if (pLabel != NULL)
	{
		pLabel->SetText(LoadStringFromResource(IDS_STRINGSOUNDOFFLINE));
		pLabel->OnEvent += MakeDelegate(OnTextEvent);
		pLabel->SetTag(UINT_PTR(this));

	}
	//////////////////check box////////////////SetCheckBtnCheck(CButtonUI *pBtnContrl, bool checked)
     InitData();
     CButtonUI*	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingNotifyOnNewsCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_notifyOnNews);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingNoNotifyMobileCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_shieldMobile);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingNotifyWayCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_TrayOnLogin);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingNotifyMsnCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_NotifyOnMailOrSMS);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingSoundCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_SoundOn);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingOffChatSoundCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_OffChatSound);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingOffMsgSoundCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_OffMsgSound);
	}
	pBtn = static_cast<CButtonUI*>(m_pManager->FindControl(kSettingOfflineCheck));
	if (pBtn != NULL)
	{
		SetCheckBtnCheck(pBtn, b_OffSoundNotOnline);
	}

}